Arc

Struct Arc 

pub struct Arc<T> { /* private fields */ }
A replacement for std::sync::Arc.

Implementations

Source

impl<T> Arc<T>

Similar to std::sync::Arc. There is no weak count and thus no Weak struct. In accordance with the deferred reclamation scheme, the ref count of the pointed-to block may not immediately be decremented on drop.

pub fn new(data: T) -> Self

pub unsafe fn get_mut_unchecked(this: &mut Self) -> &mut T

Safety

Since Guards may exist, there is no safe get_mut. It is the user’s responsibility to ensure that there are no other pointers to the same allocation.

pub unsafe fn from_raw(ptr: *const T) -> Self

pub fn ref_count(this: &Arc<T>) -> usize

Returns the number of strong (Arc or AtomicArc) pointers to this allocation.